Import and format photo and video salmon count data
import_format(input, saveit = FALSE, output)
Arguments
- input
the directory path to a CSV containing dates, and hourly video and photo counts of salmon.
- saveit
whether to save the returned data frame as a RData object
- output
if saveit = TRUE, the directory path to where to save the returned data frame
Value
a data frame of salmon counts formatted for escapement functions
Examples
if (FALSE) { # \dontrun{
import_format("salmon_counts.csv")
} # }